summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtorusedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtorusedit.h')
-rw-r--r--kpovmodeler/pmtorusedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmtorusedit.h b/kpovmodeler/pmtorusedit.h
index 1d3f4f5a..95870664 100644
--- a/kpovmodeler/pmtorusedit.h
+++ b/kpovmodeler/pmtorusedit.h
@@ -35,12 +35,13 @@ class TQCheckBox;
class PMTorusEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSphereEdit with parent and name
*/
- PMTorusEdit( TQWidget* parent, const char* name = 0 );
+ PMTorusEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMSphereEdit with parent and name
+ * Creates a PMSphereEdit with tqparent and name
*/